==> v4.2.4.tar.gz: 2fauth/resources/lang/si/commons.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Authentication Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'cancel' => 'අවලංගු',
    'update' => 'යාවත්කාල',
    'copy' => 'Copy',
    'copy_to_clipboard' => 'පසුරුපුවරුවට පිටපත්',
    'copied_to_clipboard' => 'පසුරුපුවරුවට පිටපත් කෙරිණි',
    'profile' => 'පැතිකඩ',
    'edit' => 'සංස්කරණය',
    'delete' => 'Delete',
    'disable' => 'Disable',
    'enable' => 'Enable',
    'create' => 'සාදන්න',
    'save' => 'සුරකින්න',
    'close' => 'වසන්න',
    'clear' => 'Clear',
    'clear_search' => 'Clear search',
    'demo_do_not_post_sensitive_data' => 'This is a demo app, do not post any sensitive data',
    'testing_do_not_post_sensitive_data' => 'This is a testing app, do not post any sensitive data',
    'selected' => 'selected',
    'name' => 'නම',
    'manage' => 'Manage',
    'done' => 'Done',
    'new' => 'නව',
    'back' => 'ආපසු',
    'move' => 'Move',
    'export' => 'Export',
    'all' => 'සියල්ල',
    'select_all' => 'Select all',
    'clear_selection' => 'Clear selection',
    'sort_descending' => 'Sort descending',
    'sort_ascending' => 'Sort ascending',
    'rename' => 'නැවත නම්කරන්න',
    'new_name' => 'New name',
    'options' => 'විකල්ප',
    'reload' => 'නැවත පූරණය',
    'some_data_have_changed' => 'Some data have changed. You should',
    'generate' => 'Generate',
    'generating_otp' => 'Generating OTP',
    'open_in_browser' => 'Open in browser',
    'continue' => 'Continue',
    'discard' => 'Discard',
    'about' => 'About',
    'usefull_links' => 'Usefull links',
    'environment' => 'Environment',
    'credits' => 'Credits',
    '2fauth_teaser' => 'A web app to manage your Two-Factor Authentication (2FA) accounts and generate their security codes',
    'made_with' => 'Made with',
    'ui_icons_by' => 'UI Icons by',
    'logos_by' => 'Logos by',
    'search' => 'Search',
    'resources' => 'Resources',
    'check_for_update' => 'Check for new version',
    'check_for_update_help' => 'Automatically check (once a week) and warn when a new release of 2FAuth is published on Github',
    'you_are_up_to_date' => 'This instance is up-to-date',
    '2fauth_description' => 'A web app to manage your Two-Factor Authentication (2FA) accounts and generate their security codes',
    'image_of_qrcode_to_scan' => 'Image of a QR code to scan',
    'file' => 'File',
    'or' => 'OR',
    'close_the_x_page' => 'Close the {pagetitle} page',
];

==> v5.0.1.tar.gz: 2fauth/resources/lang/si/commons.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Authentication Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'cancel' => 'අවලංගු',
    'update' => 'යාවත්කාල',
    'copy' => 'Copy',
    'copy_to_clipboard' => 'පසුරුපුවරුවට පිටපත්',
    'copied_to_clipboard' => 'පසුරුපුවරුවට පිටපත් කෙරිණි',
    'profile' => 'පැතිකඩ',
    'edit' => 'සංස්කරණය',
    'delete' => 'Delete',
    'disable' => 'Disable',
    'enable' => 'Enable',
    'create' => 'සාදන්න',
    'save' => 'සුරකින්න',
    'close' => 'වසන්න',
    'clear' => 'Clear',
    'clear_search' => 'Clear search',
    'demo_do_not_post_sensitive_data' => 'This is a demo app, do not post any sensitive data',
    'testing_do_not_post_sensitive_data' => 'This is a testing app, do not post any sensitive data',
    'selected' => 'selected',
    'name' => 'නම',
    'manage' => 'Manage',
    'done' => 'Done',
    'new' => 'නව',
    'back' => 'ආපසු',
    'move' => 'Move',
    'export' => 'Export',
    'all' => 'සියල්ල',
    'select_all' => 'Select all',
    'clear_selection' => 'Clear selection',
    'sort_descending' => 'Sort descending',
    'sort_ascending' => 'Sort ascending',
    'rename' => 'නැවත නම්කරන්න',
    'new_name' => 'New name',
    'options' => 'විකල්ප',
    'reload' => 'නැවත පූරණය',
    'refresh' => 'Refresh',
    'data_refreshed_to_reflect_server_changes' => 'Data has been refresh to reflect server-side changes',
    'generate' => 'Generate',
    'generating_otp' => 'Generating OTP',
    'open_in_browser' => 'Open in browser',
    'continue' => 'Continue',
    'discard' => 'Discard',
    'about' => 'About',
    'usefull_links' => 'Usefull links',
    'environment' => 'Environment',
    'credits' => 'Credits',
    '2fauth_teaser' => 'A web app to manage your Two-Factor Authentication (2FA) accounts and generate their security codes',
    'made_with' => 'Made with',
    'ui_icons_by' => 'UI Icons by',
    'logos_by' => 'Logos by',
    'search' => 'Search',
    'resources' => 'Resources',
    'check_for_update' => 'Check for new version',
    'check_for_update_help' => 'Automatically check (once a week) and warn when a new release of 2FAuth is published on Github',
    'you_are_up_to_date' => 'This instance is up-to-date',
    '2fauth_description' => 'A web app to manage your Two-Factor Authentication (2FA) accounts and generate their security codes',
    'image_of_qrcode_to_scan' => 'Image of a QR code to scan',
    'file' => 'File',
    'or' => 'OR',
    'close_the_x_page' => 'Close the :pagetitle page',
    'submit' => 'Submit',
    'default' => 'Default',
    'back_to_home' => 'Back to home',
    'nothing' => 'nothing',
];
